pub enum ActorStoppingReason {
Requested,
Zombie(String),
}Expand description
Why an actor is stopping.
Variants
Requested
The actor is stopping through the normal cooperative shutdown path.
Zombie(String)
The actor did not respond to hard kill, and teardown stopped waiting on it normally.