pub struct ActorHandle<A: Actor> { /* private fields */ }Expand description
ActorHandles represent a (local) serving actor. It is used to access its messaging and signal ports, as well as to synchronize with its lifecycle (e.g., providing joins). Once dropped, the handle is detached from the underlying actor instance, and there is no longer any way to join it.
Correspondingly, crate::ActorAddrs refer to (possibly) remote
actors.
Implementations
Sourceimpl<A: Actor> ActorHandle<A>
A handle to a running (local) actor.
impl<A: Actor> ActorHandle<A>
A handle to a running (local) actor.
Sourcepub fn actor_addr(&self) -> &ActorAddr
pub fn actor_addr(&self) -> &ActorAddr
The ActorAddr of the actor represented by this handle.
Sourcepub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
pub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to drain its current messages and then stop.
Sourcepub fn stop(&self, reason: &str) -> Result<(), ActorError>
pub fn stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to stop without draining ordinary queued work first.
Sourcepub fn kill(&self, reason: &str) -> Result<(), ActorError>
pub fn kill(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to terminate immediately.
Sourcepub fn status(&self) -> Receiver<ActorStatus>
pub fn status(&self) -> Receiver<ActorStatus>
A watch that observes the lifecycle state of the actor.
Sourcepub fn port<M: Message>(&self) -> PortHandle<M>where
A: Handler<M>,
pub fn port<M: Message>(&self) -> PortHandle<M>where
A: Handler<M>,
Return a port for the provided message type handled by the actor.
Sourcepub fn bind<R: Binds<A>>(&self) -> ActorRef<R>
pub fn bind<R: Binds<A>>(&self) -> ActorRef<R>
TEMPORARY: bind… TODO: we shoudl also have a default binding(?)
Sourcepub fn into_any(self) -> AnyActorHandle
pub fn into_any(self) -> AnyActorHandle
Erase this handle’s actor type, preserving only lifecycle access.