pub struct AnyActorGuard { /* private fields */ }Expand description
A type-erased guard that stops an actor when dropped.
Implementations
Sourceimpl AnyActorGuard
impl AnyActorGuard
Sourcepub fn into_inner(self) -> AnyActorHandle
pub fn into_inner(self) -> AnyActorHandle
Return the actor handle without stopping the actor.
Methods from Deref<Target = AnyActorHandle>
Sourcepub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
pub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to drain its current messages and then stop.
Sourcepub fn stop(&self, reason: &str) -> Result<(), ActorError>
pub fn stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to stop without draining ordinary queued work first.
Sourcepub fn kill(&self, reason: &str) -> Result<(), ActorError>
pub fn kill(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to terminate immediately.
Sourcepub fn status(&self) -> Receiver<ActorStatus>
pub fn status(&self) -> Receiver<ActorStatus>
A watch that observes the lifecycle state of the actor.
Sourcepub fn downcast<A: Actor>(&self) -> Option<ActorHandle<A>>
pub fn downcast<A: Actor>(&self) -> Option<ActorHandle<A>>
Attempt to recover a typed actor handle.