pub struct ActorGuard<A: Actor> { /* private fields */ }Expand description
A guard that stops an actor when dropped.
Implementations
Sourceimpl<A: Actor> ActorGuard<A>
impl<A: Actor> ActorGuard<A>
Sourcepub fn into_inner(self) -> ActorHandle<A>
pub fn into_inner(self) -> ActorHandle<A>
Return the actor handle without stopping the actor.
Methods from Deref<Target = ActorHandle<A>>
Sourcepub fn actor_addr(&self) -> &ActorAddr
pub fn actor_addr(&self) -> &ActorAddr
The ActorAddr of the actor represented by this handle.
Sourcepub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
pub fn drain_and_stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to drain its current messages and then stop.
Sourcepub fn stop(&self, reason: &str) -> Result<(), ActorError>
pub fn stop(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to stop without draining ordinary queued work first.
Sourcepub fn kill(&self, reason: &str) -> Result<(), ActorError>
pub fn kill(&self, reason: &str) -> Result<(), ActorError>
Signal the actor to terminate immediately.
Sourcepub fn status(&self) -> Receiver<ActorStatus>
pub fn status(&self) -> Receiver<ActorStatus>
A watch that observes the lifecycle state of the actor.
Sourcepub fn port<M: Message>(&self) -> PortHandle<M>where
A: Handler<M>,
pub fn port<M: Message>(&self) -> PortHandle<M>where
A: Handler<M>,
Return a port for the provided message type handled by the actor.
Sourcepub fn try_post<C, M>(
&self,
cx: &C,
message: M,
) -> Result<(), MailboxSenderError>
pub fn try_post<C, M>( &self, cx: &C, message: M, ) -> Result<(), MailboxSenderError>
Post message to this actor’s handler port for M, returning an error
if delivery fails (the actor has stopped, its mailbox is closed, or the
underlying channel is disconnected). Unlike Endpoint::post, the
caller observes the failure instead of having it reported through the
actor’s lost-message channel.